import { SDKModel } from '../../core/model.js';
import { SDKCollection } from '../../core/collection.js';
export function getRenderingHostDefaults(sdk) {
    return {
        pluginsHostConnectionStatus: 'loading',
        connectionStatus: 'loading'
    };
}
export class RenderingHostModel extends SDKModel {
    getDefaults(sdk) {
        return getRenderingHostDefaults(sdk);
    }
    defineProperties() {
        super.defineProperties();
        this.sdk.utils.defineCollectionAccessor(this, 'allComponents', this.constructExternalComponents(), {}, this.getHiddenProps());
        this.sdk.utils.defineCollectionAccessor(this, 'expandedComponents', this.constructExternalComponents(), {}, this.getHiddenProps());
        this.sdk.utils.defineCollectionAccessor(this, 'availableComponents', this.constructExternalComponents(), {}, this.getHiddenProps());
        this.sdk.utils.defineCollectionAccessor(this, 'registeredComponents', this.constructExternalComponents(), {}, this.getHiddenProps());
        this.sdk.utils.defineCollectionAccessor(this, 'registeredDatasources', this.constructDatasources(), {}, this.getHiddenProps());
        this.sdk.utils.defineCollectionAccessor(this, 'forms', this.constructForms(), {}, this.getHiddenProps());
    }
    constructExternalComponents() {
        return SDKCollection.construct(this.sdk.ExternalComponent, () => ({}));
    }
    constructDatasources() {
        return SDKCollection.construct(this.sdk.Datasource, () => ({}));
    }
    constructForms() {
        return SDKCollection.construct(this.sdk.Form, () => ({}));
    }
    // sc_horizon & sc_lang parameters are needed in order to avoid Experience Editor to
    getPreviewURL(fallback = false) {
        return this.url ? this.url + '?sc_horizon=editor&sc_lang=en' : null;
    }
    getFallbackPreviewURL() {
        return this.fallbackUrl ? this.fallbackUrl + '/api/editing/feaas' : null;
    }
    static getComponentsGroups(components) {
        console.log(components.map((c) => c.group));
        return [...new Set(components.map((c) => c.group))];
    }
    static getComponentsByGroup(components, group) {
        return components.filter((c) => c.group === group);
    }
    fetchURL() {
        // url
        this.set({ url: `https://xmc-${this.sdk.auth.tenant.name}.${this.sdk.sitecorePostfix}` });
        // fallback url
        this.sdk
            .fetchJSON(`https://xmclouddeploy-api${this.sdk.inventoryEnv === 'production' ? '' : '-' + this.sdk.inventoryEnv}.${this.sdk.sitecorePostfix}/api/hosts/v1/environment/${this.sdk.auth.tenant.getEnvironmentId()}`)
            .then((hosts) => {
            this.set({ fallbackUrl: hosts === null || hosts === void 0 ? void 0 : hosts[0].renderingEngineApplicationUrl });
        });
    }
}
//# sourceMappingURL=rendering-host.js.map