import SDKAdapter from '../../core/adapter.js'
import { SDKModel } from '../../core/model.js'
import { Datasource } from '../datasources.js'
import { SDKCollection } from '../../core/collection.js'
import { ExternalComponentModel } from './external-components.js'

export interface Form {
  id: string
  name: string
}
export interface IGetFormsResponse {
  Items: {
    Entity: {
      Id: string
      Name: string
    }
    PreviewImageUrl: string
    SiteNames: string[]
  }[]
}

export interface FormParams extends Form {
  datasources: Datasource[]
}
export interface FormModel extends FormParams {}

export class Forms extends SDKAdapter<Form> {
  async fetch() {
    return this.search()
  }

  /** Searches for tenants through inventory api request */
  async search(): Promise<Form[]> {
    const response = (await this.sdk.fetchJSON(
      `${this.sdk.formsBackend.replace('{region}', this.sdk.auth.tenant.getRegionCode())}/api/entities/filter`,
      {
        method: 'POST',
        headers: {
          Authorization: `Bearer ${this.sdk.accessToken}`
        },
        cache: 'no-cache',
        body: JSON.stringify({
          Page: 1,
          PageSize: 1000,
          WhereEntityStatus: 1
        })
      }
    )) as IGetFormsResponse

    return response?.Items.map((item) => ({
      id: item.Entity.Id,
      name: item.Entity.Name,
      thumbnail: item.PreviewImageUrl,
      siteNames: item.SiteNames
    }))
  }
}

export class FormModel extends SDKModel<Form> implements FormParams {
  get adapter() {
    return this.sdk.Forms
  }

  static onCollectionChange(forms: SDKCollection<typeof FormModel>) {
    ExternalComponentModel.setForms(forms)
    ExternalComponentModel.updateComponents(
      forms.construct().sdk.renderingHost.registeredComponents,
      forms.construct().sdk.renderingHost.expandedComponents
    )
    return forms
  }
}
