/** Collection is like a flat redux store slice. It's an array of models that can be */
import { SDKModel, SDKModelSubclass } from './model.js';
/** Subscribed to. On every change it returns a fresh array to observer */
export declare class SDKCollection<TClass extends SDKModelSubclass = SDKModelSubclass, TInstance extends InstanceType<TClass> = InstanceType<TClass>, TInterface = TInstance extends SDKModel<infer TInterface> ? TInterface : never, TMinimal = TInstance extends SDKModel<any, infer TInterface> ? TInterface : never, TID = TInstance['idStruct']> extends Array<TInstance> {
    observers: ((collection: TInstance[]) => any)[];
    constructor(...args: any);
    defineProperties(): void;
    get first(): TInstance;
    onChange(): void;
    onCollectionChange(): void;
    observe(observer: (collection: TInstance[]) => any): void;
    unobserve(observer: (collection: TInstance[]) => any): void;
    getId(object: TInstance): string;
    model: TClass;
    newInstance(): void;
    /** Construct instance of a collection model */
    construct(object?: any, isNew?: boolean): TInstance;
    transformAttributes(object?: any): any;
    getImplicitAttributes(): Partial<TInstance>;
    /** Instantiate model with default values */
    new(object: TMinimal): TInstance;
    /** Instantiate model and add it to collection */
    add(object: TMinimal): TInstance;
    /** Instantiate model and send create request without adding to collection INSERT is alias */
    post(object: TMinimal): Promise<TInstance>;
    insert(object: TMinimal): Promise<TInstance>;
    /** PUT item (with all attributes), UPDATE as alias */
    put(data: TMinimal): Promise<TInstance>;
    update(data: TMinimal): Promise<TInstance>;
    save(data: TMinimal): Promise<TInstance>;
    withId(target: string | number | TID | {
        id: string;
        status: string;
        revision: number;
    }): TInstance;
    /** DELETE item (or by id) */
    delete(target: string | number | TID): Promise<TInstance>;
    /** GET item (or by id) */
    get(target: string | number | TID | {
        id: string;
        status: string;
        revision: number;
    }): Promise<TInstance>;
    /** GET ALL items, SELECT as alias */
    fetch(options?: any): Promise<this>;
    select(options?: any): Promise<this>;
    /** GET ALL items matching criteria */
    search(options?: any): Promise<TInstance[]>;
    /** Replace all items in collections with items in given array */
    setItems(objects: (TInstance | TInterface | TMinimal)[]): this;
    /** Updates or adds item to collection */
    upsertItem(object: TInstance | TInterface | TMinimal): TInstance;
    /** Adds new item into a collection */
    addItem(object: TInstance | TInterface | TMinimal): TInstance;
    /** Patches the item in collection with matching id */
    updateItem(changes: Partial<TInstance | TInterface | TMinimal> & TID): TInstance;
    /** Swaps item for another within collection */
    replaceItem(changes: Partial<TInstance | TInterface | TMinimal> & TID): TInstance;
    /** Removes item from collection */
    removeItem(target: string | number | TID): TInstance;
    /** Gets item in collection by id or by id in object */
    getItem(target: string | number | TID): TInstance;
    /** Return plain array with models exported as plain objects */
    export(): TInterface[];
    /** Return instance of collection with new identity, but fully refering to current one */
    proxy(): this;
    /**
     * Define a collection of given models. During construction of models, the attributes returned by second callback will
     * be used as implicitly provided values
     */
    static construct<M extends SDKModelSubclass, C extends (model?: InstanceType<M>) => any, TInterface = InstanceType<M> extends SDKModel<infer TInterface> ? TInterface : never, TMinimal = InstanceType<M> extends SDKModel<any, infer TMinimal> ? TMinimal : never>(model: M, getImplicitAttributes: C): SDKCollection<M, InstanceType<M>, TInterface, Omit<TMinimal, keyof ReturnType<C>>, InstanceType<M>["idStruct"]>;
    /** Save collection as raw values for future reference */
    snapshotted?: TInterface[];
    snapshot(): this;
    prependItem(object: TInstance | TInterface | TMinimal): TInstance;
}
/** An observable collection that does not have a class assigned to it. It simply calls a function on each item */
export declare class SDKFunctionalCollection<TInstance, TMinimal = TInstance> extends SDKCollection<any, TInstance, TInstance, TMinimal> {
    constructor(transformAttributes: (...args: any) => TInstance, getId: (object: TInstance) => string);
    construct(object?: any, isNew?: boolean): any;
    export(): this;
    onCollectionChange(): this;
}
//# sourceMappingURL=collection.d.ts.map