import type { SDK } from '../sdk.js';
import SDKAdapter from './adapter.js';
import { SDKModelSchema } from './schema.js';
import { Version } from '../models/versions.js';
export type ClassExtending<T = {}> = new (...args: any[]) => T;
export type SDKModelSubclass = (new (...args: any[]) => SDKModel<any>) & {
    [K in keyof typeof SDKModel]: (typeof SDKModel)[K];
};
export declare class SDKModel<T = any, TMinimal extends Partial<T> = T, TImplicit extends Partial<T> = Partial<T>> {
    sdk: SDK;
    static schema: SDKModelSchema<SDKModelSubclass, any>;
    get adapter(): SDKAdapter<T>;
    /**
     * Create instance of a model. If no data is provided, it's just empty instance. Otherwise data needs to contain all
     * the required fields, and the model will be considered "new". Usually it is a better idea to instantiate models via
     * collections, as it provides necessary implicit attributes.
     */
    constructor(data?: TMinimal & TImplicit);
    new(data: TMinimal & Partial<TImplicit>): this;
    /**
     * To ensure that models look as plain objects all extra properties and method needs to be hidden through the use of
     * `enumerable: false` descriptors.
     */
    defineProperties(): void;
    /** Constructor hook for subclasses */
    onConstruct(): void;
    getHiddenProps(): string[];
    getDefaults(sdk: SDK): any;
    setDefaults(): this;
    /** Assign values from given object */
    set(data: Partial<this | T>): this;
    merge(data: Partial<this | T>): this;
    copyHiddenProps(data: any, overwrite?: boolean): this;
    /** Assign values and hidden properties from given object */
    assign(data: Partial<this | T>): this;
    /** Set previously saved valeus to the model, returns clone */
    populate(data: Partial<this | T>): this;
    /** Return clone if any of given values are different */
    change(data: Partial<this | T>): this;
    put(data?: Partial<this | T>): Promise<this>;
    save(data?: Partial<this | T>): Promise<this>;
    update(data?: Partial<this | T>): Promise<this>;
    post(data?: Partial<this | T>): Promise<this>;
    insert(data?: Partial<this | T>): Promise<this>;
    delete(): Promise<this>;
    get(): Promise<this>;
    fetch(options?: any): Promise<this[]>;
    select(options?: any): Promise<this[]>;
    search(query?: any): Promise<this[]>;
    /** Create new instance of this class */
    construct(data?: Partial<this | T>): this;
    /** Clone instance retaining data & hidden properties */
    clone(data?: Partial<this | T>): this;
    /** Returns plain object without any descriptors or prototype */
    export(): T;
    serialize(): T;
    /** Clone mode, and assign its initial values as `snappshoted` property */
    snapshotted?: T;
    snapshot(): this;
    /** Default sorting logic */
    sortCompare(other: this): number;
    /** Get object's id */
    id: string;
    idStruct: {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: Version['status'];
    };
    getId(): string;
    /** Returns object that has fresh identity but references same collection */
    /** Useful for shallow equality checked deps */
    proxy(): this;
    onChange(): void;
    observers: ((...args: any) => any)[];
    observe(observer: (model: this) => any): void;
    unobserve(observer: (model: this) => any): void;
    /** Hook to redefine new instance detection */
    _isNew: boolean;
    get isNew(): boolean;
    set isNew(value: boolean);
    /** Compares changes */
    isEqual(other: this, ignoreProps?: string[]): boolean;
    compareProp(property: keyof this, value1: any, value2: any): boolean;
    static onCollectionChange(collection: any[]): any[];
    /** Apply normalization on style */
    static transformAttributes(object: any): any;
}
//# sourceMappingURL=model.d.ts.map