/// <reference types="node" resolution-mode="require"/>
import { LibraryModel } from '../models/libraries.js';
export type FetchOptions = Parameters<typeof fetch>[1];
type FetchPreflight = (url: string, options?: FetchOptions) => Promise<FetchOptions>;
export interface TransportOptions {
    backend: string;
    cdn: string;
    frontend: string;
    formsBackend?: string;
    inventory: string;
    inventoryEnv: string;
    sitecorePostfix: string;
    accessToken: string;
    apiKey: string;
    preflight: FetchPreflight;
    library?: LibraryModel;
    verbose?: boolean;
    useProxy?: boolean;
    onError: (e?: Error, message?: string) => any;
}
export interface Transport extends TransportOptions {
}
export declare let nanoid: (t?: number) => string;
export declare function getCrypto(): Promise<typeof crypto>;
export declare function getFetch(): Promise<typeof fetch>;
export declare class HTTPError extends Error {
    status: number;
    cause: Error | string;
    constructor(message: string, details: {
        cause?: any;
        status: number;
    });
}
export declare class Transport<T = TransportOptions> implements TransportOptions {
    static cryptoPromise: Promise<typeof crypto>;
    static fetchPromise: Promise<typeof fetch>;
    static crypto: typeof crypto;
    static fetch: typeof fetch;
    static nanoid: (t?: number) => string;
    static defaults: Partial<TransportOptions>;
    nanoid: (t?: number) => string;
    constructor(options?: Partial<T>);
    checkFetchResponse(response: Response): Promise<Response>;
    parseObjectDates: (object: any) => any;
    log(...args: any[]): void;
    fetch(url: string, options?: FetchOptions): Promise<Response>;
    fetchJSON(url: string, options?: FetchOptions): Promise<any>;
    fetchExternalJSON(url: string, options?: FetchOptions): Promise<any>;
    proxyJSON(url: string, options?: FetchOptions): Promise<any>;
    proxy(url: string, options?: FetchOptions): Promise<Response>;
    signUpload(category: string): Promise<any>;
    uploadBlob(category: 'uploads' | 'images' | 'thumbnails' | 'webcomponents', name: string, blob: Buffer | Blob | ArrayBufferView | ArrayBuffer, options?: FetchOptions): Promise<{
        url: string;
    }>;
    reportError(e: Error, message?: string): void;
}
export default Transport;
//# sourceMappingURL=transport.d.ts.map