import type { User, Auth0ContextInterface, GetTokenSilentlyOptions, GetIdTokenClaimsOptions, IdToken } from '@auth0/auth0-react';
import { SDKModel } from '../core/model.js';
import { SDK, TenantModel } from '../index.js';
export declare class AuthError extends Error {
    name: string;
}
export interface QueryContext {
    tenantName?: string;
    organization?: string;
    systemId?: string;
}
export declare enum TokenCustomClaimKeysEnum {
    ORG_DISPLAY_NAME = "https://auth.sitecorecloud.io/claims/org_display_name",
    ORG_ID = "https://auth.sitecorecloud.io/claims/org_id",
    ORG_NAME = "https://auth.sitecorecloud.io/claims/org_name",
    ROLES = "https://auth.sitecorecloud.io/claims/roles",
    ORG_TYPE = "https://auth.sitecorecloud.io/claims/org_type"
}
export interface ITokenClaims {
    __raw: string;
    name?: string;
    given_name?: string;
    family_name?: string;
    middle_name?: string;
    nickname?: string;
    preferred_username?: string;
    profile?: string;
    picture?: string;
    website?: string;
    email?: string;
    email_verified?: boolean;
    gender?: string;
    birthdate?: string;
    zoneinfo?: string;
    locale?: string;
    phone_number?: string;
    phone_number_verified?: boolean;
    address?: string;
    updated_at?: string;
    iss?: string;
    aud?: string;
    exp?: number;
    nbf?: number;
    iat?: number;
    jti?: string;
    azp?: string;
    nonce?: string;
    auth_time?: string;
    at_hash?: string;
    c_hash?: string;
    acr?: string;
    amr?: string;
    sub_jwk?: string;
    cnf?: string;
    sid?: string;
    org_id?: string;
    [TokenCustomClaimKeysEnum.ORG_DISPLAY_NAME]: string;
    [TokenCustomClaimKeysEnum.ORG_ID]: string;
    [TokenCustomClaimKeysEnum.ORG_DISPLAY_NAME]: string;
    [TokenCustomClaimKeysEnum.ROLES]: string[];
    [TokenCustomClaimKeysEnum.ORG_TYPE]: string;
    [key: string]: any;
}
export interface ITokenClaimsWithAccountOrgId extends ITokenClaims {
    [TokenCustomClaimOrgAccountIdKey]: string;
}
export declare const TokenCustomClaimOrgAccountIdKey = "https://auth.sitecorecloud.io/claims/org_account_id";
export interface Auth extends Omit<Auth0ContextInterface<User>, 'getAccessTokenSilently'> {
    getIdTokenClaims: (options?: GetIdTokenClaimsOptions) => Promise<IdToken | undefined>;
    getAccessTokenSilently: (props?: GetTokenSilentlyOptions) => Promise<string>;
    login: (query: any) => void;
    _logout: Auth['logout'];
    isExternal: () => boolean;
    claims: ITokenClaims;
}
export interface AuthModel extends Auth {
}
export declare function getAuthDefaults(sdk: SDK): {
    isAuthenticated: boolean;
    isLoading: boolean;
    user: User;
    loginWithRedirect: () => void;
    logout: () => void;
};
export declare class AuthModel extends SDKModel<Auth> implements Auth {
    tenant?: TenantModel;
    getDefaults(sdk: SDK): {
        isAuthenticated: boolean;
        isLoading: boolean;
        user: User;
        loginWithRedirect: () => void;
        logout: () => void;
    };
    isExternal(): boolean;
    get logout(): (options?: import("@auth0/auth0-react").LogoutOptions) => void;
    set logout(callback: (options?: import("@auth0/auth0-react").LogoutOptions) => void);
    retrieveClaims(): Promise<void>;
    /** Re-authenticate the user. This method is safe to call multiple times, it will only initiate authentication
     * if necessary: If user is not yet logged in, or the user logged in to wrong organization */
    login(query: any): Promise<boolean>;
    getUser(): {
        id?: undefined;
        name?: undefined;
        givenName?: undefined;
        familyName?: undefined;
        email?: undefined;
        picture?: undefined;
        nickname?: undefined;
    } | {
        id: string;
        name: string;
        givenName: string;
        familyName: string;
        email: string;
        picture: string;
        nickname: string;
    };
    getGainsightUserData(): {
        userFields: {
            id: string;
            email: string;
            firstName: string;
            lastName: string;
        };
        accountFields: {
            id: any;
            sfdcId: any;
        };
    };
    getGainsightGlobalContext(): {
        'Organization DisplayName': string;
        OrganizationID: string;
        'Organization Role': string;
        'Organization Type': string;
    };
    getDefaultContext(): Partial<QueryContext>;
    getContext(query: QueryContext): {
        tenantName?: string;
        organization?: string;
        systemId?: string;
    };
    initPreflight(query: any, audience: string): void;
    /**
     * - Fetch tenant by tenantName (query or localstorage)
     * - If tenant has access to project/lib, use this tenant
     * - Else fetch all tenants for the user, search if there is a tenant that has access to project/lib and use this tenant
     * - If the user has no tenants at all, throw corresponding error
     * - If user has tenants but none has access to project/lib, throw corresponding error
     */
    findTenant(query: any, systemId: string, libraryId: string): Promise<TenantModel>;
    static setLocalStorageContext(context: QueryContext): void;
    static getContextFromQuery(query: QueryContext): QueryContext;
    static getContextFromUser(user: typeof AuthModel.prototype.user): QueryContext;
    static getContextFromLocalStorage(): QueryContext;
    static formatContextForAuth0(context: QueryContext): {
        tenant_name: string;
        organization_id: string;
        system_id: string;
    };
}
//# sourceMappingURL=auth.d.ts.map