import { SDKModel } from '../../core/model.js';
import { ObjectSchema, UISchema, ExternalComponent as ExternalComponentOriginal } from '@sitecore/byoc';
import { ComponentModel, SDKCollection } from '../../index.js';
import { Form } from './forms.js';
import { Context } from '../../style/context.js';
export type { ObjectSchema, UISchema } from '@sitecore/byoc';
export type ExternalComponent = ExternalComponentOriginal;
export type EmbeddableComponent = ExternalComponent | ComponentModel;
export declare class ExternalComponentModel extends SDKModel<ExternalComponent> implements ExternalComponent {
    name: string;
    id: string;
    schema: ObjectSchema;
    title: string;
    uiSchema: UISchema;
    component: any;
    thumbnail: string;
    group: string;
    isHidden: boolean;
    datasourceIds: string[];
    links: Record<string, string>;
    meta: Record<string, string>;
    siteNames: string[];
    /** Get settings for all datasoruces used in component */
    getDataSettings(): Record<string, import("../datasources.js").DataSettings>;
    /** We consider that components that come from @sitecore/components package will have a name with the "Sitecore" prefix */
    isSitecoreComponent(): boolean;
    getImportStatement(): string;
    static getDefinition(context: Context): {
        readonly type: "html";
        readonly title: "HTML Embed";
        readonly getConfiguration: (context: Context) => string;
        readonly condition: (context: Context) => boolean;
        readonly isRenderable: false;
    } | {
        readonly type: "form";
        readonly title: "Sitecore Form";
        readonly getConfiguration: (context: Context) => any;
        readonly condition: (context: Context) => boolean;
        readonly isRenderable: false;
    } | {
        readonly type: "feaas";
        readonly title: "Sitecore component";
        readonly getConfiguration: (context: Context) => boolean;
        readonly condition: (context: Context) => boolean;
        readonly isRenderable: true;
    } | {
        readonly type: "web";
        readonly title: "Web component";
        readonly getConfiguration: (context: Context) => any;
        readonly condition: (context: Context) => boolean;
        readonly isRenderable: true;
    } | {
        readonly type: "byoc";
        readonly title: "Component";
        readonly getConfiguration: (context: Context) => any;
        readonly condition: (context: Context) => boolean;
        readonly isRenderable: false;
    };
    static loadFromSessionStorage(): any;
    static storeToSessionStorage(components: ExternalComponent[]): void;
    static components: ExternalComponent[];
    static setComponents(components: ExternalComponent[]): void;
    static forms: Form[];
    static setForms(forms: Form[]): void;
    static updateComponents(collection: SDKCollection<typeof ExternalComponentModel>, expandedCollection: SDKCollection<typeof ExternalComponentModel>, expandedList?: ExternalComponent[], components?: ExternalComponent[]): void;
    static isFormsEnabled: boolean;
    static getExpandedComponents(): ExternalComponent[];
    static isComponentForm(component: ExternalComponent): boolean;
    static isExternalComponent(component: any): component is ExternalComponent;
}
//# sourceMappingURL=external-components.d.ts.map