import { ExternalComponentModel } from './external-components.js';
import { DatasourceModel } from '../datasources.js';
import { SDKModel } from '../../core/model.js';
import { SDKCollection } from '../../core/collection.js';
import { FormModel } from './forms.js';
import { SDK } from '../../sdk.js';
export interface RenderingHost {
    url: string;
    fallbackUrl: string;
    availableComponents: Partial<ExternalComponentModel>[];
    registeredComponents: Partial<ExternalComponentModel>[];
    allComponents: Partial<ExternalComponentModel>[];
    expandedComponents: Partial<ExternalComponentModel>[];
    forms: Partial<FormModel>[];
    registeredDatasources: Partial<DatasourceModel>[];
    pluginsHostConnectionStatus: 'loading' | 'success' | 'error';
    connectionStatus: 'loading' | 'success' | 'error';
}
export interface RenderingHostModel extends RenderingHost {
}
export declare function getRenderingHostDefaults(sdk: SDK): {
    pluginsHostConnectionStatus: string;
    connectionStatus: string;
};
export declare class RenderingHostModel extends SDKModel<RenderingHost> implements RenderingHost {
    allComponents: ReturnType<this['constructExternalComponents']>;
    expandedComponents: ReturnType<this['constructExternalComponents']>;
    availableComponents: ReturnType<this['constructExternalComponents']>;
    registeredComponents: ReturnType<this['constructExternalComponents']>;
    registeredDatasources: ReturnType<this['constructDatasources']>;
    forms: ReturnType<this['constructForms']>;
    getDefaults(sdk: SDK): {
        pluginsHostConnectionStatus: string;
        connectionStatus: string;
    };
    defineProperties(): void;
    constructExternalComponents(): SDKCollection<typeof ExternalComponentModel, ExternalComponentModel, import("./external-components.js").ExternalComponent, Omit<import("./external-components.js").ExternalComponent & Partial<Partial<import("./external-components.js").ExternalComponent>>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    constructDatasources(): SDKCollection<typeof DatasourceModel, DatasourceModel, import("../datasources.js").Datasource, Omit<Pick<Partial<import("../datasources.js").Datasource>, "type" | "id" | "definition" | "settings" | "createdAt" | "modifiedAt" | "sampledAt" | "conflictDefinition"> & Omit<import("../datasources.js").Datasource, "type" | "id" | "definition" | "settings" | "createdAt" | "modifiedAt" | "sampledAt" | "conflictDefinition"> & Partial<import("../datasources.js").DatasourceImplicit>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    constructForms(): SDKCollection<typeof FormModel, FormModel, import("./forms.js").Form, Omit<import("./forms.js").Form & Partial<Partial<import("./forms.js").Form>>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    getPreviewURL(fallback?: boolean): string;
    getFallbackPreviewURL(): string;
    static getComponentsGroups(components: ExternalComponentModel[]): string[];
    static getComponentsByGroup(components: ExternalComponentModel[], group: string): ExternalComponentModel[];
    fetchURL(): void;
}
//# sourceMappingURL=rendering-host.d.ts.map