import SDKAdapter from '../../core/adapter.js';
import { SDKCollection } from '../../core/collection.js';
import { SDKModel } from '../../core/model.js';
import { SDKModelSchema } from '../../core/schema.js';
import { QueryContext } from '../auth.js';
import { Datasource } from '../datasources.js';
import { Library } from '../libraries.js';
export declare class TenantError extends Error {
    name: string;
}
interface ITenantData {
    [key: string]: string | number | boolean;
    URL?: string;
}
declare type ITenantLabels = ITenantData;
declare type Annotations = ITenantData;
export interface Tenant {
    annotations?: Annotations;
    id: string;
    name: string;
    displayName: string;
    organizationId: string;
    serviceId: string;
    labels: ITenantLabels;
    systemId: string;
}
export interface IGetTenantsResponse {
    totalCount: number;
    pageSize: number;
    pageNumber: number;
    data: Tenant[];
}
export interface TenantParams extends Tenant {
    datasources: Datasource[];
}
export interface TenantModel extends TenantParams {
}
export declare class Tenants extends SDKAdapter<Tenant> {
    fetch(query: {
        name?: string;
        authorization?: string;
        xmProjectId?: string;
        limit?: number;
        systemId: string;
    }): Promise<Tenant[]>;
    /** Searches for tenants through inventory api request */
    search(query: {
        name?: string;
        authorization?: string;
        xmProjectId?: string;
        limit?: number;
        systemId: string;
    }): Promise<Tenant[]>;
}
export declare const RegionsMap: {
    'West Europe': string;
    'East US': string;
    'West US': string;
    'West US 2': string;
    'Japan East': string;
    'East Japan': string;
    'Australia East': string;
    'East Australia': string;
    'Southeast Asia': string;
    eu1: string;
    us1: string;
    us2: string;
    jp1: string;
    au1: string;
};
export declare class TenantModel extends SDKModel<Tenant> implements TenantParams {
    datasources: ReturnType<this['constructDatasources']>;
    get adapter(): Tenants;
    defineProperties(): void;
    getHiddenProps(): string[];
    constructDatasources(): SDKCollection<typeof import("../datasources.js").DatasourceModel, import("../datasources.js").DatasourceModel, Datasource, Omit<Pick<Partial<Datasource>, "type" | "id" | "definition" | "settings" | "createdAt" | "modifiedAt" | "sampledAt" | "conflictDefinition"> & Omit<Datasource, "type" | "id" | "definition" | "settings" | "createdAt" | "modifiedAt" | "sampledAt" | "conflictDefinition"> & Partial<import("../datasources.js").DatasourceImplicit>, "type" | "externalSourceId">, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    constructForms(): SDKCollection<typeof import("./forms.js").FormModel, import("./forms.js").FormModel, import("./forms.js").Form, Omit<import("./forms.js").Form & Partial<Partial<import("./forms.js").Form>>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    getRegionCode(): string;
    getProjectId(): string;
    getProjectName(): string;
    getURL(): string;
    getEnvironmentId(): string;
    getContext(): QueryContext;
    static generateProjectIdFromTenant(tenant: Tenant): string;
    static generateProjectNameFromTenant(tenant: Tenant): string;
    static get schema(): SDKModelSchema<typeof TenantModel, Library>;
}
export {};
//# sourceMappingURL=tenants.d.ts.map