import type { CollectionModel } from './collections.js';
import { ComponentModel } from './components.js';
import type { LibraryModel } from './libraries.js';
import { SDKModel } from '../core/model.js';
import SDKAdapter from '../core/adapter.js';
import { Atleast, Optional, RequiredKeys, SDK } from '../sdk.js';
import { Version, VersionModel } from './versions.js';
import * as Style from '../style/index.js';
import { SDKModelSchema } from '../index.js';
export interface VersionBundle {
    id: string;
    libraryId: LibraryModel['id'];
    componentId: ComponentModel['id'];
    name: string;
    description?: string;
    breakpoints: {
        [key: string]: string;
    };
    orderIdx?: string;
    createdAt: Date;
    modifiedAt: Date;
}
export declare function getVersionBundleDefaults(sdk: SDK): {
    id: string;
    createdAt: Date;
    modifiedAt: Date;
    breakpoints: {};
};
export type VersionBundleMinimal<T extends keyof VersionBundle = never> = RequiredKeys<VersionBundle, typeof getVersionBundleDefaults, T>;
export interface VersionBundleImplicit {
    /** Does version represent bundle? */
    library?: LibraryModel;
    libraryId: LibraryModel['id'];
    collectionId?: CollectionModel['id'];
    collection?: CollectionModel;
    componentId: ComponentModel['id'];
    component?: ComponentModel;
}
export interface VersionBundleParams extends VersionBundle, VersionBundleImplicit {
}
export interface VersionBundleModel extends VersionBundleParams {
}
export declare class VersionBundles extends SDKAdapter<VersionBundle> {
    fetch(version: Pick<VersionBundleParams, 'libraryId' | 'collectionId' | 'componentId'>): Promise<VersionBundle[]>;
    get(version: Pick<VersionBundleParams, 'id' | 'collectionId' | 'libraryId' | 'componentId'>): Promise<VersionBundle>;
    post(version: Optional<VersionBundleParams, 'componentId'> & Atleast<VersionBundleParams, 'libraryId' | 'collectionId' | 'componentId'>): Promise<any>;
    put(version: Optional<VersionBundleParams, 'componentId'> & Atleast<VersionBundleParams, 'libraryId' | 'collectionId' | 'componentId'>): Promise<any>;
    delete(version: Atleast<VersionBundleParams, 'libraryId' | 'collectionId' | 'componentId'>): Promise<any>;
}
export declare class VersionBundleModel extends SDKModel<VersionBundle, VersionBundleMinimal, VersionBundleImplicit> implements VersionBundleParams {
    get adapter(): VersionBundles;
    getDefaults(sdk: SDK): {
        id: string;
        createdAt: Date;
        modifiedAt: Date;
        breakpoints: {};
    };
    getHiddenProps(): string[];
    aggregate(status: VersionModel['status'], versions?: VersionModel[]): VersionModel;
    getHTML(versions: VersionModel[], map?: Record<string, Style.RuleWithProps<"breakpoint", {
        minWidth: number;
        maxWidth: number;
        query: string;
    }>[]>): string;
    getVersionMap(versions: VersionModel[]): Record<string, Style.RuleWithProps<"breakpoint", {
        minWidth: number;
        maxWidth: number;
        query: string;
    }>[]>;
    getAvailableVersionsForBreakpoint(breakpoint: Style.Rule<'breakpoint'>, versions?: VersionModel[]): VersionModel[];
    getVersionForBreakpoint(breakpoint: Style.Rule<'breakpoint'>, status?: Version['status'][] | Version['status'], explicitVersions?: VersionModel[]): VersionModel;
    getUsedVersions(): VersionModel[];
    static get schema(): SDKModelSchema<typeof VersionModel, VersionBundle>;
    getWarnings(): {
        breakpoint: Style.RuleWithProps<"breakpoint", {
            minWidth: number;
            maxWidth: number;
            query: string;
        }>;
        warning: {
            versionId: string;
            label: string;
            breakpoints: Style.RuleWithProps<"breakpoint", {
                minWidth: number;
                maxWidth: number;
                query: string;
            }>[];
            description: string;
        };
    }[];
}
//# sourceMappingURL=version-bundles.d.ts.map