import { SDKCollection } from './core/collection.js';
import { SDKModel } from './core/model.js';
import Transport from './core/transport.js';
import { AuthModel } from './models/auth.js';
import { CollectionModel, Collections } from './models/collections.js';
import { ComponentModel, Components } from './models/components.js';
import { ContentHubOneDatasources, DatasourceModel, Datasources, XmDatasources } from './models/datasources.js';
import { ContentHubOneContentTypeModel } from './models/external/content-hub-one-content-types.js';
import { ExternalComponentModel } from './models/external/external-components.js';
import { FormModel, Forms } from './models/external/forms.js';
import { TenantModel, Tenants } from './models/external/tenants.js';
import { XmTemplateModel } from './models/external/xm-templates.js';
import { Libraries, LibraryModel, TemplateLibraries } from './models/libraries.js';
import { StylesheetModel, Stylesheets } from './models/stylesheets.js';
import { VersionBundleModel, VersionBundles } from './models/version-bundles.js';
import { VersionModel, Versions } from './models/versions.js';
import * as Style from './style/index.js';
import * as CSS from './utils/css.js';
import * as utils from './utils/index.js';
import { RenderingHostModel } from './models/external/rendering-host.js';
export * from './style/embed.js';
export * from './utils/index.js';
export { Style, CSS };
export declare class SDK extends Transport {
    Libraries: Libraries;
    Collections: Collections;
    Components: Components;
    Tenants: Tenants;
    Versions: Versions;
    VersionBundles: VersionBundles;
    Stylesheets: Stylesheets;
    Datasources: Datasources;
    XmDatasources: XmDatasources;
    ContentHubOneDatasources: ContentHubOneDatasources;
    TemplateLibraries: TemplateLibraries;
    Forms: Forms;
    Collection: typeof CollectionModel;
    Component: typeof ComponentModel;
    ExternalComponent: typeof ExternalComponentModel;
    Version: typeof VersionModel;
    VersionBundle: typeof VersionBundleModel;
    Library: typeof LibraryModel;
    Stylesheet: typeof StylesheetModel;
    Style: typeof Style.RuleConstructor & typeof import("./style/methods/rule.js") & {
        fix<T extends "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">(style: Style.Rule<T>, rules: Style.Rule<"fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">[]): Style.Rule<T>;
        isValid(rule: Style.Rule<"fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">): {
            red: number;
            green: number;
            blue: number;
            alpha: number;
        } | {
            backgroundImage: any;
            backgroundPositionX: Style.Length;
            backgroundPositionY: Style.Length;
            backgroundRepeat: Style.TypeDefinitions.fill.BackgroundRepeat;
            backgroundSize: Style.TypeDefinitions.fill.BackgroundSize;
            blur: Style.Length;
            opacity: number;
            backgroundColor: Style.ColorReference;
            backgroundGradient: {
                angle: number;
                stops: {
                    color: Style.ColorReference | {
                        red: number;
                        green: number;
                        blue: number;
                        alpha: number;
                    };
                    start: Style.Length;
                    end: Style.Length;
                }[];
            };
        } | {
            minWidth: number;
            maxWidth: number;
            query: string;
        } | {
            type: "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme";
        } | {
            familyName: string;
            platform: Style.TypeDefinitions.font.Platform;
            variants: {
                name: string;
                familyName: string;
                weight: number;
                style: Style.TypeDefinitions.font.VariantStyle;
            }[];
        } | {
            url: any;
        } | {
            boxShadowInset: boolean;
            boxShadowOffsetX: Style.Length;
            boxShadowOffsetY: Style.Length;
            boxShadowBlurRadius: Style.Length;
            boxShadowSpreadRadius: Style.Length;
            boxShadowColor: Style.ColorReference;
            borderTopLeftRadius: Style.Length;
            borderTopRightRadius: Style.Length;
            borderBottomLeftRadius: Style.Length;
            borderBottomRightRadius: Style.Length;
            borderStyle: Style.TypeDefinitions.decoration.BorderStyle;
            borderColor: Style.ColorReference;
            borderLeftWidth: Style.Length;
            borderRightWidth: Style.Length;
            borderTopWidth: Style.Length;
            borderBottomWidth: Style.Length;
        } | {
            minWidth: Style.Length;
            maxWidth: Style.Length;
            minHeight: Style.Length;
            maxHeight: Style.Length;
        } | {
            columns: {
                min: Style.Length;
                max: Style.Length;
            }[];
            rows: {
                min: Style.Length;
                max: Style.Length;
            }[];
            items: {
                order: number;
                from: {
                    row: number;
                    column: number;
                };
                to: {
                    row: number;
                    column: number;
                };
            }[];
        } | {
            flexWrap: boolean;
            columnCount: number;
            weights: number[];
            justifyContent: Style.TypeDefinitions.layout.JustifyContent;
            alignItems: Style.TypeDefinitions.layout.AlignItems;
        } | {
            textAlign: Style.TypeDefinitions.lines.TextAlign;
            lines: number;
            ellipsis: boolean;
            wordBreak: Style.TypeDefinitions.lines.WordBreak;
        } | {
            width: Style.Length;
            height: Style.Length;
            objectFit: Style.TypeDefinitions.media.Fit;
            objectPositionX: Style.Length;
            objectPositionY: Style.Length;
        } | {
            textColor: Style.ColorReference;
            linkDecoration: Style.TypeDefinitions.palette.LinkDecorationStyle;
        } | {
            paddingTop: Style.Length;
            paddingBottom: Style.Length;
            paddingLeft: Style.Length;
            paddingRight: Style.Length;
            rowGap: Style.Length;
            columnGap: Style.Length;
        } | {
            fontVariant: any;
            allowBoldAndItalic: boolean;
            textTransform: any;
            base: {
                fontSize: Style.Length;
                lineHeight: Style.Length;
                letterSpacing: Style.Length;
                paragraphSpacing: Style.Length;
                iconSize: Style.Length;
            };
            overrides: Record<string, {
                fontSize: Style.Length;
                lineHeight: Style.Length;
                letterSpacing: Style.Length;
                paragraphSpacing: Style.Length;
                iconSize: Style.Length;
            }>;
        } | {
            fillIds: string[];
            decorationIds: string[];
            layoutIds: string[];
            gridIds: string[];
            spacingIds: string[];
            paletteIds: string[];
        } | {
            typographyIds: string[];
            decorationIds: string[];
            fillIds: string[];
            graphicIds: string[];
            paletteIds: string[];
            spacingIds: string[];
        } | {
            typographyIds: string[];
            paletteIds: string[];
        } | {
            blocks: {
                id: string;
                refId: string;
                fillId: string;
                decorationId: string;
                spacingId: string;
                typographyId: string;
                paletteId: string;
                isDefault: boolean;
            }[];
            inlines: {
                id: string;
                refId: string;
                fillId: string;
                decorationId: string;
                spacingId: string;
                typographyId: string;
                paletteId: string;
                isDefault: boolean;
            }[];
            texts: {
                id: string;
                refId: string;
                fillId: string;
                decorationId: string;
                spacingId: string;
                typographyId: string;
                paletteId: string;
                isDefault: boolean;
            }[];
        };
        isInCategory<T_1 extends "aspect" | "basic" | "element" | "concept">(style: Style.Rule<"fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">, category: T_1): style is Style.Rule<Style.TypesByCategory[T_1]>;
        forCollection(collection: Style.RuleWithProps<"collection", {
            type: "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme";
        }>): Style.Rule<"fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">;
    } & typeof Style;
    Datasource: typeof DatasourceModel;
    Tenant: typeof TenantModel;
    XmTemplate: typeof XmTemplateModel;
    Form: typeof FormModel;
    Auth: typeof AuthModel;
    RenderingHost: typeof RenderingHostModel;
    ContentHubOne: typeof ContentHubOneContentTypeModel;
    libraries: SDKCollection<typeof LibraryModel, LibraryModel, any, Omit<Pick<Partial<import("./models/libraries.js").Library>, "id" | "settings" | "apiKey" | "templateId"> & Omit<import("./models/libraries.js").Library, "id" | "settings" | "apiKey" | "templateId"> & Partial<Partial<import("./models/libraries.js").Library>>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    templateLibraries: SDKCollection<typeof LibraryModel, LibraryModel, any, Omit<Pick<Partial<import("./models/libraries.js").Library>, "id" | "settings" | "apiKey" | "templateId"> & Omit<import("./models/libraries.js").Library, "id" | "settings" | "apiKey" | "templateId"> & Partial<Partial<import("./models/libraries.js").Library>>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    tenants: SDKCollection<typeof TenantModel, TenantModel, import("./models/external/tenants.js").Tenant, Omit<import("./models/external/tenants.js").Tenant & Partial<Partial<import("./models/external/tenants.js").Tenant>>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    library: LibraryModel;
    get externalComponents(): SDKCollection<typeof ExternalComponentModel, ExternalComponentModel, import("./models/external/external-components.js").ExternalComponent, Omit<import("./models/external/external-components.js").ExternalComponent & Partial<Partial<import("./models/external/external-components.js").ExternalComponent>>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    get externalDatasources(): SDKCollection<typeof DatasourceModel, DatasourceModel, import("./models/datasources.js").Datasource, Omit<Pick<Partial<import("./models/datasources.js").Datasource>, "type" | "id" | "definition" | "settings" | "createdAt" | "modifiedAt" | "sampledAt" | "conflictDefinition"> & Omit<import("./models/datasources.js").Datasource, "type" | "id" | "definition" | "settings" | "createdAt" | "modifiedAt" | "sampledAt" | "conflictDefinition"> & Partial<import("./models/datasources.js").DatasourceImplicit>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    datasources: SDKCollection<typeof DatasourceModel, DatasourceModel, import("./models/datasources.js").Datasource, Omit<Pick<Partial<import("./models/datasources.js").Datasource>, "type" | "id" | "definition" | "settings" | "createdAt" | "modifiedAt" | "sampledAt" | "conflictDefinition"> & Omit<import("./models/datasources.js").Datasource, "type" | "id" | "definition" | "settings" | "createdAt" | "modifiedAt" | "sampledAt" | "conflictDefinition"> & Partial<import("./models/datasources.js").DatasourceImplicit>, never>, {
        id: string;
    } | {
        details: {
            id: string;
        };
    } | {
        id: string;
        revision: number;
        status: "published" | "draft" | "staged" | "saved";
    }>;
    static instance: SDK;
    utils: typeof utils;
    CSS: typeof CSS;
    static Library: typeof LibraryModel;
    static Collection: typeof CollectionModel;
    static Component: typeof ComponentModel;
    static ExternalComponent: typeof ExternalComponentModel;
    static Version: typeof VersionModel;
    static Stylesheet: typeof StylesheetModel;
    static Style: typeof Style;
    static Datasource: typeof DatasourceModel;
    static Tenant: typeof TenantModel;
    static XmTemplate: typeof XmTemplateModel;
    auth: AuthModel;
    renderingHost: RenderingHostModel;
    normalizeHTML(html: string): string;
    getFrontendURL(target: string | {
        getPath: () => string;
    }): string;
    getContextQuery(): string;
    getBackendURL(model: SDKModel & {
        getPath: () => string;
    }): string;
}
//# sourceMappingURL=sdk.d.ts.map