import type * as Style from './index.js';
import * as TypeDefinitions from './types/index.js';
import type { GroupBy } from '../utils/typescript.js';
import type { Unformatted } from '../utils/value.js';
export type TypeDefinitionsByCategory = GroupBy<(typeof TypeDefinitions)[keyof typeof TypeDefinitions], 'category'>;
export type TypeDefinitionGeneric<Props, T extends Style.Type, Category extends 'basic' | 'aspect' | 'element' | 'concept'> = {
    Props: (props: Unformatted<Props>) => Props;
    validate: (props: Props) => boolean;
    fix: (props: Props, styles: Style.Rule[]) => Props;
    type: T;
    category: Category;
    label: string;
    forms?: T extends Style.Type.ElementAspect | Style.Type.Basic ? Style.Form<Props>[] : never;
    aspects?: T extends Style.Type.Element ? readonly Style.Type.Aspect[] : never;
    summarize?: (props: Props, styles?: Style.Rule[], form?: string) => string;
};
export { TypeDefinitions };
export type TypesByCategory = {
    [key in keyof TypeDefinitionsByCategory]: TypeDefinitionsByCategory[key]['type'];
};
export type Category = keyof TypesByCategory;
export type TypeDefinition<T extends Style.Type = Style.Type> = (typeof TypeDefinitions)[T];
export type TypeDefinitionCategory<T extends Category = Category> = TypeDefinitionsByCategory[T];
export declare function isTypeInCategory<C extends Category>(type: Style.Type, category: C): type is TypesByCategory[C];
export declare function isTypeElementAspect(type: Style.Type): type is Style.Type.ElementAspect;
export declare function getAspects<T extends Style.Type>(type: T): ("fill" | "decoration" | "palette" | "spacing" | "typography")[];
export declare function getForms<T extends Style.Type>(type: T): ({
    id: string;
    label: string;
    extractProperties: (props: {
        backgroundImage: any;
        backgroundPositionX: Style.Length;
        backgroundPositionY: Style.Length;
        backgroundRepeat: Style.Fill.BackgroundRepeat;
        backgroundSize: Style.Fill.BackgroundSize;
        blur: Style.Length;
        opacity: number;
        backgroundColor: Style.ColorReference;
        backgroundGradient: {
            angle: number;
            stops: {
                color: Style.ColorReference | {
                    red: number;
                    green: number;
                    blue: number;
                    alpha: number;
                };
                start: Style.Length;
                end: Style.Length;
            }[];
        };
    }) => {
        backgroundColor: Style.ColorReference;
        backgroundGradient: {
            angle: number;
            stops: {
                color: Style.ColorReference | {
                    red: number;
                    green: number;
                    blue: number;
                    alpha: number;
                };
                start: Style.Length;
                end: Style.Length;
            }[];
        };
    };
    validate: ({ backgroundColor, backgroundGradient }: {
        backgroundColor: Style.ColorReference;
        backgroundGradient: {
            angle: number;
            stops: {
                color: Style.ColorReference | {
                    red: number;
                    green: number;
                    blue: number;
                    alpha: number;
                };
                start: Style.Length;
                end: Style.Length;
            }[];
        };
    }) => boolean;
} | {
    id: string;
    label: string;
    extractProperties: (props: {
        backgroundImage: any;
        backgroundPositionX: Style.Length;
        backgroundPositionY: Style.Length;
        backgroundRepeat: Style.Fill.BackgroundRepeat;
        backgroundSize: Style.Fill.BackgroundSize;
        blur: Style.Length;
        opacity: number;
        backgroundColor: Style.ColorReference;
        backgroundGradient: {
            angle: number;
            stops: {
                color: Style.ColorReference | {
                    red: number;
                    green: number;
                    blue: number;
                    alpha: number;
                };
                start: Style.Length;
                end: Style.Length;
            }[];
        };
    }) => {
        blur: Style.Length;
        opacity: number;
    };
    validate: ({ blur, opacity }: {
        blur: Style.Length;
        opacity: number;
    }) => boolean;
})[] | ({
    id: string;
    label: string;
    extractProperties: (props: {
        boxShadowInset: boolean;
        boxShadowOffsetX: Style.Length;
        boxShadowOffsetY: Style.Length;
        boxShadowBlurRadius: Style.Length;
        boxShadowSpreadRadius: Style.Length;
        boxShadowColor: Style.ColorReference;
        borderTopLeftRadius: Style.Length;
        borderTopRightRadius: Style.Length;
        borderBottomLeftRadius: Style.Length;
        borderBottomRightRadius: Style.Length;
        borderStyle: Style.Decoration.BorderStyle;
        borderColor: Style.ColorReference;
        borderLeftWidth: Style.Length;
        borderRightWidth: Style.Length;
        borderTopWidth: Style.Length;
        borderBottomWidth: Style.Length;
    }) => {
        borderTopLeftRadius: Style.Length;
        borderTopRightRadius: Style.Length;
        borderBottomLeftRadius: Style.Length;
        borderBottomRightRadius: Style.Length;
    };
    validate: (props: {
        borderTopLeftRadius: Style.Length;
        borderTopRightRadius: Style.Length;
        borderBottomLeftRadius: Style.Length;
        borderBottomRightRadius: Style.Length;
    }) => boolean;
} | {
    id: string;
    label: string;
    extractProperties: (props: {
        boxShadowInset: boolean;
        boxShadowOffsetX: Style.Length;
        boxShadowOffsetY: Style.Length;
        boxShadowBlurRadius: Style.Length;
        boxShadowSpreadRadius: Style.Length;
        boxShadowColor: Style.ColorReference;
        borderTopLeftRadius: Style.Length;
        borderTopRightRadius: Style.Length;
        borderBottomLeftRadius: Style.Length;
        borderBottomRightRadius: Style.Length;
        borderStyle: Style.Decoration.BorderStyle;
        borderColor: Style.ColorReference;
        borderLeftWidth: Style.Length;
        borderRightWidth: Style.Length;
        borderTopWidth: Style.Length;
        borderBottomWidth: Style.Length;
    }) => {
        boxShadowInset: boolean;
        boxShadowOffsetX: Style.Length;
        boxShadowOffsetY: Style.Length;
        boxShadowBlurRadius: Style.Length;
        boxShadowSpreadRadius: Style.Length;
        boxShadowColor: Style.ColorReference;
    };
    validate: (props: {
        boxShadowInset: boolean;
        boxShadowOffsetX: Style.Length;
        boxShadowOffsetY: Style.Length;
        boxShadowBlurRadius: Style.Length;
        boxShadowSpreadRadius: Style.Length;
        boxShadowColor: Style.ColorReference;
    }) => boolean;
} | {
    id: string;
    label: string;
    extractProperties: (props: {
        boxShadowInset: boolean;
        boxShadowOffsetX: Style.Length;
        boxShadowOffsetY: Style.Length;
        boxShadowBlurRadius: Style.Length;
        boxShadowSpreadRadius: Style.Length;
        boxShadowColor: Style.ColorReference;
        borderTopLeftRadius: Style.Length;
        borderTopRightRadius: Style.Length;
        borderBottomLeftRadius: Style.Length;
        borderBottomRightRadius: Style.Length;
        borderStyle: Style.Decoration.BorderStyle;
        borderColor: Style.ColorReference;
        borderLeftWidth: Style.Length;
        borderRightWidth: Style.Length;
        borderTopWidth: Style.Length;
        borderBottomWidth: Style.Length;
    }) => {
        borderStyle: Style.Decoration.BorderStyle;
        borderColor: Style.ColorReference;
        borderLeftWidth: Style.Length;
        borderRightWidth: Style.Length;
        borderTopWidth: Style.Length;
        borderBottomWidth: Style.Length;
    };
    validate: (props: {
        borderStyle: Style.Decoration.BorderStyle;
        borderColor: Style.ColorReference;
        borderLeftWidth: Style.Length;
        borderRightWidth: Style.Length;
        borderTopWidth: Style.Length;
        borderBottomWidth: Style.Length;
    }) => boolean;
})[] | {
    label: string;
    id: string;
    extractProperties: (props?: any) => {
        textColor: Style.ColorReference;
        linkDecoration: Style.Palette.LinkDecorationStyle;
    };
    validate: () => boolean;
}[] | {
    label: string;
    id: string;
    extractProperties: (props?: any) => {
        paddingTop: Style.Length;
        paddingBottom: Style.Length;
        paddingLeft: Style.Length;
        paddingRight: Style.Length;
        rowGap: Style.Length;
        columnGap: Style.Length;
    };
    validate: () => boolean;
}[] | ({
    id: string;
    label: string;
    extractProperties: ({ fontVariant }: {
        fontVariant: any;
        allowBoldAndItalic: boolean;
        textTransform: any;
        base: {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        };
        overrides: Record<string, {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        }>;
    }) => {
        fontVariant: any;
    };
    validate: ({ fontVariant }: Partial<{
        fontVariant: any;
        allowBoldAndItalic: boolean;
        textTransform: any;
        base: {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        };
        overrides: Record<string, {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        }>;
    }>) => boolean;
} | {
    id: string;
    label: string;
    extractProperties: (props: {
        fontVariant: any;
        allowBoldAndItalic: boolean;
        textTransform: any;
        base: {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        };
        overrides: Record<string, {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        }>;
    }) => {
        base: {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        };
    };
    validate: (props: {
        fontVariant: any;
        allowBoldAndItalic: boolean;
        textTransform: any;
        base: {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        };
        overrides: Record<string, {
            fontSize: Style.Length;
            lineHeight: Style.Length;
            letterSpacing: Style.Length;
            paragraphSpacing: Style.Length;
            iconSize: Style.Length;
        }>;
    }) => boolean;
})[] | {
    id: string;
    label: string;
    extractProperties: (props: {
        red: number;
        green: number;
        blue: number;
        alpha: number;
    }) => {
        red: number;
        green: number;
        blue: number;
        alpha: number;
    };
    validate: () => boolean;
}[] | {
    id: string;
    label: string;
    extractProperties: (props: {
        minWidth: number;
        maxWidth: number;
        query: string;
    }) => {
        minWidth: number;
        maxWidth: number;
        query: string;
    };
    validate: () => boolean;
}[] | Style.Form<any>[] | {
    id: string;
    label: string;
    extractProperties: (props: {
        familyName: string;
        platform: Style.Font.Platform;
        variants: {
            name: string;
            familyName: string;
            weight: number;
            style: Style.Font.VariantStyle;
        }[];
    }) => {
        familyName: string;
        platform: Style.Font.Platform;
        variants: {
            name: string;
            familyName: string;
            weight: number;
            style: Style.Font.VariantStyle;
        }[];
    };
    validate: () => boolean;
}[] | {
    id: string;
    label: string;
    extractProperties: (props: {
        url: any;
    }) => {
        url: any;
    };
    validate: () => boolean;
}[];
//# sourceMappingURL=definition.d.ts.map