import { TypeDefinitions } from './definition.js';
import type { Rule } from './rule.js';
import type { Style } from '../sdk.js';
export type Type = keyof typeof TypeDefinitions;
export type Props = {
    [T in Type]: ReturnType<(typeof TypeDefinitions)[T]['Props']>;
};
export declare function fix<T extends Type>(type: T, props: Props[T], styles: Rule[]): Props[T];
export declare function PropsConstructor<T extends Type>(type: T, props: Props[T], styles: Rule[]): {
    red: number;
    green: number;
    blue: number;
    alpha: number;
} | {
    backgroundImage: any;
    backgroundPositionX: Style.Length;
    backgroundPositionY: Style.Length;
    backgroundRepeat: TypeDefinitions.fill.BackgroundRepeat;
    backgroundSize: TypeDefinitions.fill.BackgroundSize;
    blur: Style.Length;
    opacity: number;
    backgroundColor: Style.ColorReference;
    backgroundGradient: {
        angle: number;
        stops: {
            color: Style.ColorReference | {
                red: number;
                green: number;
                blue: number;
                alpha: number;
            };
            start: Style.Length;
            end: Style.Length;
        }[];
    };
} | {
    minWidth: number;
    maxWidth: number;
    query: string;
} | {
    type: "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme";
} | {
    familyName: string;
    platform: TypeDefinitions.font.Platform;
    variants: {
        name: string;
        familyName: string;
        weight: number;
        style: TypeDefinitions.font.VariantStyle;
    }[];
} | {
    url: any;
} | {
    boxShadowInset: boolean;
    boxShadowOffsetX: Style.Length;
    boxShadowOffsetY: Style.Length;
    boxShadowBlurRadius: Style.Length;
    boxShadowSpreadRadius: Style.Length;
    boxShadowColor: Style.ColorReference;
    borderTopLeftRadius: Style.Length;
    borderTopRightRadius: Style.Length;
    borderBottomLeftRadius: Style.Length;
    borderBottomRightRadius: Style.Length;
    borderStyle: TypeDefinitions.decoration.BorderStyle;
    borderColor: Style.ColorReference;
    borderLeftWidth: Style.Length;
    borderRightWidth: Style.Length;
    borderTopWidth: Style.Length;
    borderBottomWidth: Style.Length;
} | {
    minWidth: Style.Length;
    maxWidth: Style.Length;
    minHeight: Style.Length;
    maxHeight: Style.Length;
} | {
    columns: {
        min: Style.Length;
        max: Style.Length;
    }[];
    rows: {
        min: Style.Length;
        max: Style.Length;
    }[];
    items: {
        order: number;
        from: {
            row: number;
            column: number;
        };
        to: {
            row: number;
            column: number;
        };
    }[];
} | {
    flexWrap: boolean;
    columnCount: number;
    weights: number[];
    justifyContent: TypeDefinitions.layout.JustifyContent;
    alignItems: TypeDefinitions.layout.AlignItems;
} | {
    textAlign: TypeDefinitions.lines.TextAlign;
    lines: number;
    ellipsis: boolean;
    wordBreak: TypeDefinitions.lines.WordBreak;
} | {
    width: Style.Length;
    height: Style.Length;
    objectFit: TypeDefinitions.media.Fit;
    objectPositionX: Style.Length;
    objectPositionY: Style.Length;
} | {
    textColor: Style.ColorReference;
    linkDecoration: TypeDefinitions.palette.LinkDecorationStyle;
} | {
    paddingTop: Style.Length;
    paddingBottom: Style.Length;
    paddingLeft: Style.Length;
    paddingRight: Style.Length;
    rowGap: Style.Length;
    columnGap: Style.Length;
} | {
    fontVariant: any;
    allowBoldAndItalic: boolean;
    textTransform: any;
    base: {
        fontSize: Style.Length;
        lineHeight: Style.Length;
        letterSpacing: Style.Length;
        paragraphSpacing: Style.Length;
        iconSize: Style.Length;
    };
    overrides: Record<string, {
        fontSize: Style.Length;
        lineHeight: Style.Length;
        letterSpacing: Style.Length;
        paragraphSpacing: Style.Length;
        iconSize: Style.Length;
    }>;
} | {
    fillIds: string[];
    decorationIds: string[];
    layoutIds: string[];
    gridIds: string[];
    spacingIds: string[];
    paletteIds: string[];
} | {
    typographyIds: string[];
    paletteIds: string[];
} | {
    blocks: {
        id: string;
        refId: string;
        fillId: string;
        decorationId: string;
        spacingId: string;
        typographyId: string;
        paletteId: string;
        isDefault: boolean;
    }[];
    inlines: {
        id: string;
        refId: string;
        fillId: string;
        decorationId: string;
        spacingId: string;
        typographyId: string;
        paletteId: string;
        isDefault: boolean;
    }[];
    texts: {
        id: string;
        refId: string;
        fillId: string;
        decorationId: string;
        spacingId: string;
        typographyId: string;
        paletteId: string;
        isDefault: boolean;
    }[];
} | Style.Props.Props[T];
export declare function summarize<T extends Style.Type.Aspect>(type: T, props: Props[T], styles?: Style.Rule[], formId?: string): string;
export declare const Props: typeof PropsConstructor & {
    fix: typeof fix;
};
//# sourceMappingURL=props.d.ts.map