import type { Optional } from '../index.js';
import type { MergeInterfaces, Unformatted } from '../utils/value.js';
import { TypeDefinitions } from './definition.js';
import { Details } from './details.js';
import * as RuleMethods from './methods/rule.js';
import { Props } from './props.js';
import { TypesByCategory } from './definition.js';
import type { Type } from './type.js';
export type Rule<T extends Type = Type> = RuleByType[T];
export declare namespace Rule {
    type Basic = Rule<Type.Basic>;
    type Aspect = Rule<Type.Aspect>;
    type Element = Rule<Type.Element>;
    type Concept = Rule<Type.Concept>;
    type ElementAspect<T extends Type.Element = Type.Element> = Rule<Type.ElementAspect<T>>;
    type ElementWithAspect<T extends Type.Aspect> = Rule<Type.ElementWithAspect<T>>;
}
export declare namespace RuleCollection {
    type Element<T extends Type.Element = Type.Element> = RuleWithProps<'collection', TypeDefinitions.collection.Props<T>>;
}
export type RuleCollection<T extends Type = Type> = RuleWithProps<'collection', TypeDefinitions.collection.Props<T>>;
export interface Empty {
    type: Type;
}
export type RuleMerged<T extends Type> = RuleWithProps<T, Partial<MergeInterfaces<Props[T]>>>;
export interface RuleWithProps<T, P> {
    type: T;
    props: P;
    details: Details;
}
export type typeOf<R extends RuleWithProps<Type, any>> = R extends RuleWithProps<infer T extends Type, any> ? T : never;
export type typesOf<R extends RuleWithProps<Type, any>[]> = R extends RuleWithProps<infer T extends Type, any>[] ? T : never;
export type RuleByType = {
    [id in Type]: RuleWithProps<id, Props[id]>;
};
export type AspectsByType<T extends Type.Element = Type.Element> = {
    [key in (typeof TypeDefinitions)[T]['aspects'][number]]: Rule<key>[];
};
export type AspectByType<T extends Type.Element = Type.Element> = {
    [key in (typeof TypeDefinitions)[T]['aspects'][number]]: Rule<key>;
};
export declare function RuleConstructor<T extends Type>({ type, details, props }: {
    type: T;
    details?: Unformatted<Optional<Details, 'title' | 'description' | 'id'>>;
    props?: Unformatted<Props[T]>;
}): Rule<T>;
export declare const RuleShortcuts: {
    fix<T extends "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">(style: Rule<T>, rules: Rule[]): Rule<T>;
    /** Ensure that basic shape of a style is correct  */
    isValid(rule: Rule): {
        red: number;
        green: number;
        blue: number;
        alpha: number;
    } | {
        backgroundImage: any;
        backgroundPositionX: import("./index.js").Length;
        backgroundPositionY: import("./index.js").Length;
        backgroundRepeat: TypeDefinitions.fill.BackgroundRepeat;
        backgroundSize: TypeDefinitions.fill.BackgroundSize;
        blur: import("./index.js").Length;
        opacity: number;
        backgroundColor: import("./index.js").ColorReference;
        backgroundGradient: {
            angle: number;
            stops: {
                color: import("./index.js").ColorReference | {
                    red: number;
                    green: number;
                    blue: number;
                    alpha: number;
                };
                start: import("./index.js").Length;
                end: import("./index.js").Length;
            }[];
        };
    } | {
        minWidth: number;
        maxWidth: number;
        query: string;
    } | {
        type: "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme";
    } | {
        familyName: string;
        platform: TypeDefinitions.font.Platform;
        variants: {
            name: string;
            familyName: string;
            weight: number;
            style: TypeDefinitions.font.VariantStyle;
        }[];
    } | {
        url: any;
    } | {
        boxShadowInset: boolean;
        boxShadowOffsetX: import("./index.js").Length;
        boxShadowOffsetY: import("./index.js").Length;
        boxShadowBlurRadius: import("./index.js").Length;
        boxShadowSpreadRadius: import("./index.js").Length;
        boxShadowColor: import("./index.js").ColorReference;
        borderTopLeftRadius: import("./index.js").Length;
        borderTopRightRadius: import("./index.js").Length;
        borderBottomLeftRadius: import("./index.js").Length;
        borderBottomRightRadius: import("./index.js").Length;
        borderStyle: TypeDefinitions.decoration.BorderStyle;
        borderColor: import("./index.js").ColorReference;
        borderLeftWidth: import("./index.js").Length;
        borderRightWidth: import("./index.js").Length;
        borderTopWidth: import("./index.js").Length;
        borderBottomWidth: import("./index.js").Length;
    } | {
        minWidth: import("./index.js").Length;
        maxWidth: import("./index.js").Length;
        minHeight: import("./index.js").Length;
        maxHeight: import("./index.js").Length;
    } | {
        columns: {
            min: import("./index.js").Length;
            max: import("./index.js").Length;
        }[];
        rows: {
            min: import("./index.js").Length;
            max: import("./index.js").Length;
        }[];
        items: {
            order: number;
            from: {
                row: number;
                column: number;
            };
            to: {
                row: number;
                column: number;
            };
        }[];
    } | {
        flexWrap: boolean;
        columnCount: number;
        weights: number[];
        justifyContent: TypeDefinitions.layout.JustifyContent;
        alignItems: TypeDefinitions.layout.AlignItems;
    } | {
        textAlign: TypeDefinitions.lines.TextAlign;
        lines: number;
        ellipsis: boolean;
        wordBreak: TypeDefinitions.lines.WordBreak;
    } | {
        width: import("./index.js").Length;
        height: import("./index.js").Length;
        objectFit: TypeDefinitions.media.Fit;
        objectPositionX: import("./index.js").Length;
        objectPositionY: import("./index.js").Length;
    } | {
        textColor: import("./index.js").ColorReference;
        linkDecoration: TypeDefinitions.palette.LinkDecorationStyle;
    } | {
        paddingTop: import("./index.js").Length;
        paddingBottom: import("./index.js").Length;
        paddingLeft: import("./index.js").Length;
        paddingRight: import("./index.js").Length;
        rowGap: import("./index.js").Length;
        columnGap: import("./index.js").Length;
    } | {
        fontVariant: any;
        allowBoldAndItalic: boolean;
        textTransform: any;
        base: {
            fontSize: import("./index.js").Length;
            lineHeight: import("./index.js").Length;
            letterSpacing: import("./index.js").Length;
            paragraphSpacing: import("./index.js").Length;
            iconSize: import("./index.js").Length;
        };
        overrides: Record<string, {
            fontSize: import("./index.js").Length;
            lineHeight: import("./index.js").Length;
            letterSpacing: import("./index.js").Length;
            paragraphSpacing: import("./index.js").Length;
            iconSize: import("./index.js").Length;
        }>;
    } | {
        fillIds: string[];
        decorationIds: string[];
        layoutIds: string[];
        gridIds: string[];
        spacingIds: string[];
        paletteIds: string[];
    } | {
        typographyIds: string[];
        decorationIds: string[];
        fillIds: string[];
        graphicIds: string[];
        paletteIds: string[];
        spacingIds: string[];
    } | {
        typographyIds: string[];
        paletteIds: string[];
    } | {
        blocks: {
            id: string;
            refId: string;
            fillId: string;
            decorationId: string;
            spacingId: string;
            typographyId: string;
            paletteId: string;
            isDefault: boolean;
        }[];
        inlines: {
            id: string;
            refId: string;
            fillId: string;
            decorationId: string;
            spacingId: string;
            typographyId: string;
            paletteId: string;
            isDefault: boolean;
        }[];
        texts: {
            id: string;
            refId: string;
            fillId: string;
            decorationId: string;
            spacingId: string;
            typographyId: string;
            paletteId: string;
            isDefault: boolean;
        }[];
    };
    isInCategory<T_1 extends "aspect" | "basic" | "element" | "concept">(style: Rule, category: T_1): style is Rule<TypesByCategory[T_1]>;
    /** A constructor for newly created rules for a given collection. Assigns some default values */
    forCollection(collection: RuleWithProps<"collection", {
        type: "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme";
    }>): Rule<"fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">;
};
export type RuleError<T extends Rule = Rule> = Partial<{
    details?: Partial<T['details']>;
    props?: {
        [key in keyof T['props']]: string;
    };
}> | null;
export declare const Rule: typeof RuleConstructor & typeof RuleMethods & {
    fix<T extends "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">(style: Rule<T>, rules: Rule[]): Rule<T>;
    /** Ensure that basic shape of a style is correct  */
    isValid(rule: Rule): {
        red: number;
        green: number;
        blue: number;
        alpha: number;
    } | {
        backgroundImage: any;
        backgroundPositionX: import("./index.js").Length;
        backgroundPositionY: import("./index.js").Length;
        backgroundRepeat: TypeDefinitions.fill.BackgroundRepeat;
        backgroundSize: TypeDefinitions.fill.BackgroundSize;
        blur: import("./index.js").Length;
        opacity: number;
        backgroundColor: import("./index.js").ColorReference;
        backgroundGradient: {
            angle: number;
            stops: {
                color: import("./index.js").ColorReference | {
                    red: number;
                    green: number;
                    blue: number;
                    alpha: number;
                };
                start: import("./index.js").Length;
                end: import("./index.js").Length;
            }[];
        };
    } | {
        minWidth: number;
        maxWidth: number;
        query: string;
    } | {
        type: "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme";
    } | {
        familyName: string;
        platform: TypeDefinitions.font.Platform;
        variants: {
            name: string;
            familyName: string;
            weight: number;
            style: TypeDefinitions.font.VariantStyle;
        }[];
    } | {
        url: any;
    } | {
        boxShadowInset: boolean;
        boxShadowOffsetX: import("./index.js").Length;
        boxShadowOffsetY: import("./index.js").Length;
        boxShadowBlurRadius: import("./index.js").Length;
        boxShadowSpreadRadius: import("./index.js").Length;
        boxShadowColor: import("./index.js").ColorReference;
        borderTopLeftRadius: import("./index.js").Length;
        borderTopRightRadius: import("./index.js").Length;
        borderBottomLeftRadius: import("./index.js").Length;
        borderBottomRightRadius: import("./index.js").Length;
        borderStyle: TypeDefinitions.decoration.BorderStyle;
        borderColor: import("./index.js").ColorReference;
        borderLeftWidth: import("./index.js").Length;
        borderRightWidth: import("./index.js").Length;
        borderTopWidth: import("./index.js").Length;
        borderBottomWidth: import("./index.js").Length;
    } | {
        minWidth: import("./index.js").Length;
        maxWidth: import("./index.js").Length;
        minHeight: import("./index.js").Length;
        maxHeight: import("./index.js").Length;
    } | {
        columns: {
            min: import("./index.js").Length;
            max: import("./index.js").Length;
        }[];
        rows: {
            min: import("./index.js").Length;
            max: import("./index.js").Length;
        }[];
        items: {
            order: number;
            from: {
                row: number;
                column: number;
            };
            to: {
                row: number;
                column: number;
            };
        }[];
    } | {
        flexWrap: boolean;
        columnCount: number;
        weights: number[];
        justifyContent: TypeDefinitions.layout.JustifyContent;
        alignItems: TypeDefinitions.layout.AlignItems;
    } | {
        textAlign: TypeDefinitions.lines.TextAlign;
        lines: number;
        ellipsis: boolean;
        wordBreak: TypeDefinitions.lines.WordBreak;
    } | {
        width: import("./index.js").Length;
        height: import("./index.js").Length;
        objectFit: TypeDefinitions.media.Fit;
        objectPositionX: import("./index.js").Length;
        objectPositionY: import("./index.js").Length;
    } | {
        textColor: import("./index.js").ColorReference;
        linkDecoration: TypeDefinitions.palette.LinkDecorationStyle;
    } | {
        paddingTop: import("./index.js").Length;
        paddingBottom: import("./index.js").Length;
        paddingLeft: import("./index.js").Length;
        paddingRight: import("./index.js").Length;
        rowGap: import("./index.js").Length;
        columnGap: import("./index.js").Length;
    } | {
        fontVariant: any;
        allowBoldAndItalic: boolean;
        textTransform: any;
        base: {
            fontSize: import("./index.js").Length;
            lineHeight: import("./index.js").Length;
            letterSpacing: import("./index.js").Length;
            paragraphSpacing: import("./index.js").Length;
            iconSize: import("./index.js").Length;
        };
        overrides: Record<string, {
            fontSize: import("./index.js").Length;
            lineHeight: import("./index.js").Length;
            letterSpacing: import("./index.js").Length;
            paragraphSpacing: import("./index.js").Length;
            iconSize: import("./index.js").Length;
        }>;
    } | {
        fillIds: string[];
        decorationIds: string[];
        layoutIds: string[];
        gridIds: string[];
        spacingIds: string[];
        paletteIds: string[];
    } | {
        typographyIds: string[];
        decorationIds: string[];
        fillIds: string[];
        graphicIds: string[];
        paletteIds: string[];
        spacingIds: string[];
    } | {
        typographyIds: string[];
        paletteIds: string[];
    } | {
        blocks: {
            id: string;
            refId: string;
            fillId: string;
            decorationId: string;
            spacingId: string;
            typographyId: string;
            paletteId: string;
            isDefault: boolean;
        }[];
        inlines: {
            id: string;
            refId: string;
            fillId: string;
            decorationId: string;
            spacingId: string;
            typographyId: string;
            paletteId: string;
            isDefault: boolean;
        }[];
        texts: {
            id: string;
            refId: string;
            fillId: string;
            decorationId: string;
            spacingId: string;
            typographyId: string;
            paletteId: string;
            isDefault: boolean;
        }[];
    };
    isInCategory<T_1 extends "aspect" | "basic" | "element" | "concept">(style: Rule, category: T_1): style is Rule<TypesByCategory[T_1]>;
    /** A constructor for newly created rules for a given collection. Assigns some default values */
    forCollection(collection: RuleWithProps<"collection", {
        type: "fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme";
    }>): Rule<"fill" | "color" | "breakpoint" | "collection" | "font" | "graphic" | "decoration" | "dimensions" | "grid" | "layout" | "lines" | "media" | "palette" | "spacing" | "typography" | "block" | "inline" | "text" | "theme">;
};
//# sourceMappingURL=rule.d.ts.map